#!/bin/sh

set -x

[ -z "$MKDIRP" ] && exit 1
[ -z "$RMF" ] && exit 1
[ -z "$LNS" ] && exit 1
[ -z "$INS" ] && exit 1
[ -z "$JAVADIR" ] && exit 1
[ -z "$JAVADOCDIR" ] && exit 1
[ -z "$NBDIR" ] && exit 1
[ -z "$JHJAR" ] && exit 1

setup() {
	# generate empty javax.script file, so there is something in jsr223 API module
	$MKDIRP libs.jsr223/src/javax/script
	echo "package javax.script; class empty { }" > libs.jsr223/src/javax/script/empty.java
	$MKDIRP libs.jsr223/external
	$RMF libs.jsr223/external/binaries-list
	jar cf libs.jsr223/external/jsr223-api.jar libs.jsr223/src/javax/script/empty.java
	$LNS $JAVADIR/swing-layout.jar o.jdesktop.layout/external/swing-layout-1.0.3.jar
	$RMF o.jdesktop.layout/external/binaries-list
	$LNS $JAVADIR/$JHJAR apisupport.harness/external/jsearch-2.0_05.jar
	$RMF apisupport.harness/external/binaries-list
	$LNS $JAVADIR/$JHJAR javahelp/external/jh-2.0_05.jar
	$RMF javahelp/external/binaries-list
        $LNS $JAVADIR/jna.jar libs.jna/external/jna-3.0.2.jar
	$RMF libs.jna/external/binaries-list
}
	
build() {
	ant \
	-Dpermit.jdk6.builds=true \
	-Dbuild.compiler.deprecation=false \
	-Dbuild.compiler.debug=false \
	-Dverify.checkout=false \
	-f nbbuild/build.xml build-platform
}        
        

install() {
	$RMF nbbuild/netbeans/platform9/modules/ext/swing-layout-1.0.3.jar
	$RMF nbbuild/netbeans/platform9/modules/ext/jsearch-2.0_05.jar
	$RMF nbbuild/netbeans/platform9/modules/ext/jh-2.0_05.jar
	echo > nbbuild/netbeans/platform9/.noautoupdate
        $MKDIRP $NBDIR/platform9
	$INS nbbuild/netbeans/platform9/* ${NBDIR}/platform9
	$INS nbbuild/netbeans/platform9/.noautoupdate ${NBDIR}/platform9
	$LNS ${JAVADIR}/swing-layout.jar ${NBDIR}/platform9/modules/ext/swing-layout-1.0.3.jar
	$LNS ${JAVADIR}/$JHJAR ${NBDIR}/platform9/modules/ext/jh-2.0_05.jar
}


build_devel() {
	ant \
	-Dpermit.jdk6.builds=true \
	-Dbuild.compiler.deprecation=false \
	-Dbuild.compiler.debug=false \
	-Dverify.checkout=false \
	-f apisupport.harness/build.xml
}


install_devel() {
	$RMF nbbuild/netbeans/harness/jsearch-2.0_05.jar
	echo > nbbuild/netbeans/harness/.noautoupdate
        $MKDIRP $NBDIR/harness
	$INS nbbuild/netbeans/harness/* $NBDIR/harness
	$INS nbbuild/netbeans/harness/.noautoupdate $NBDIR/harness
	$LNS $JAVADIR/$JHJAR $NBDIR/harness/jsearch-2.0_05.jar
}

build_javadoc() {	
	ant \
	-Dpermit.jdk6.builds=true \
	-Dbuild.compiler.deprecation=false \
	-Dbuild.compiler.debug=false \
	-Dverify.checkout=false \
	-Dallmodules= \
	-Dcluster.config=platform \
	-Dconfig.javadoc.cluster=platform9 \
	-Dconfig.javadoc.netbeans=\
openide.util,openide.actions,openide.options,openide.awt,\
openide.dialogs,openide.nodes,openide.explorer,openide.fs,openide.modules,\
openide.text,openide.windows,openide.loaders,openide.io,queries,\
api.progress,api.visual,autoupdate.services,settings,javahelp,openide.execution,\
sendopts,editor.mimelookup,options.api, \
	-Djavadoc.docs.org-netbeans-api-java=http://bits.netbeans.org/6.1/javadoc/org-netbeans-api-java/ \
	-Djavadoc.docs.org-netbeans-modules-project-ant=http://bits.netbeans.org/6.1/javadoc/org-netbeans-modules-project-ant/ \
	-Djavadoc.docs.org-netbeans-modules-projectapi=http://bits.netbeans.org/6.1/javadoc/org-netbeans-modules-projectapi/ \
	-f nbbuild/build.xml build-javadoc
}

install_javadoc() {
	# copy core platform files
	$RMF nbbuild/build/javadoc/*.zip
        $MKDIRP $JAVADOCDIR
	$INS nbbuild/build/javadoc/* $JAVADOCDIR
}




case $1 in
setup)
	setup 
        ;;
build)
	build
        ;;
build_devel)
	build_devel
        ;;
build_javadoc)
	build_javadoc
        ;;
install)
	install
        ;;
install_devel)
	install_devel
        ;;
install_javadoc)
	install_javadoc
        ;;
*)
	exit 1
        ;;
esac

